@@ -37,11 +37,7 @@
 #include "ephy-profile-utils.h"
 #include "ephy-settings.h"
 #include "ephy-sqlite-connection.h"
-#include "ephy-uri-helpers.h"
 #include "ephy-web-app-utils.h"
-#ifdef ENABLE_NSS
-#include "ephy-nss-glue.h"
-#endif
 
 #include <fcntl.h>
 #include <glib/gi18n.h>
@@ -127,291 +123,6 @@ migrate_cookies (void)
   g_free (dest);
 }
 
-#ifdef ENABLE_NSS
-static char *
-decrypt (const char *data)
-{
-  unsigned char *plain;
-  gsize out_len;
-
-  /* The old style password is encoded in base64. They are identified
-   * by a leading '~'. Otherwise, we should decrypt the text.
-   */
-  plain = g_base64_decode (data, &out_len);
-  if (data[0] != '~') {
-    char *decrypted;
-
-    decrypted = ephy_nss_glue_decrypt (plain, out_len);
-    g_free (plain);
-    plain = (unsigned char *)decrypted;
-  }
-
-  return (char *)plain;
-}
-
-static void
-parse_and_decrypt_signons (const char *signons,
-                           gboolean    handle_forms)
-{
-  int version;
-  gchar **lines;
-  guint i;
-  guint length;
-
-  lines = g_strsplit (signons, "\r\n", -1);
-  if (!g_ascii_strncasecmp (lines[0], "#2c", 3))
-    version = 1;
-  else if (!g_ascii_strncasecmp (lines[0], "#2d", 3))
-    version = 2;
-  else if (!g_ascii_strncasecmp (lines[0], "#2e", 3))
-    version = 3;
-  else
-    goto out;
-
-  /* Skip the never-saved list */
-  for (i = 1; lines[i] && !g_str_equal (lines[i], "."); i++) {
-    ;
-  }
-
-  i++;
-
-  /*
-   * Read saved passwords. The information is stored in blocks
-   * separated by lines that only contain a dot. We find a block by
-   * the separator and parse them one by one.
-   */
-  length = g_strv_length (lines);
-
-  while (i < length) {
-    size_t begin = i;
-    size_t end = i + 1;
-    const char *realmBracketBegin = " (";
-    const char *realmBracketEnd = ")";
-    SoupURI *uri = NULL;
-    char *realm = NULL;
-
-    while (lines[end] && !g_str_equal (lines[end], "."))
-      end++;
-
-    i = end + 1;
-
-    /* A block has at least five lines */
-    if (end - begin < 5)
-      continue;
-
-    /* The first line is the site URL.
-     * For HTTP authentication logins, the URL may contain http realm,
-     * which will be in bracket:
-     *   sitename:8080 (realm)
-     */
-    if (g_strstr_len (lines[begin], -1, realmBracketBegin)) {
-      char *start_ptr, *end_ptr;
-      char *full_url, *url;
-      glong start, ending;
-
-      /* In this case the scheme may not exist. We assume that the
-       * scheme is HTTP.
-       */
-      if (!g_strstr_len (lines[begin], -1, "://"))
-        full_url = g_strconcat ("http://", lines[begin], NULL);
-      else
-        full_url = g_strdup (lines[begin]);
-
-      start_ptr = g_strstr_len (full_url, -1, realmBracketBegin);
-      start = g_utf8_pointer_to_offset (full_url, start_ptr);
-      url = g_utf8_substring (full_url, 0, start);
-      url = g_strstrip (url);
-      uri = soup_uri_new (url);
-      g_free (url);
-
-      start += strlen (realmBracketBegin);
-      end_ptr = g_strstr_len (full_url, -1, realmBracketEnd) - 1;
-      ending = g_utf8_pointer_to_offset (full_url, end_ptr);
-      realm = g_utf8_substring (full_url, start, ending);
-
-      g_free (full_url);
-    } else {
-      /* Don't have HTTP realm. It is the URL that the following
-       * password belongs to.
-       */
-      uri = soup_uri_new (lines[begin]);
-    }
-
-    if (!SOUP_URI_VALID_FOR_HTTP (uri)) {
-      soup_uri_free (uri);
-      g_free (realm);
-      continue;
-    }
-
-    ++begin;
-
-    /* There may be multiple username/password pairs for this site.
-     * In this case, they are saved in one block without a separated
-     * line (contains a dot).
-     */
-    while (begin + 4 < end) {
-      char *username = NULL;
-      char *password = NULL;
-      char *form_username = NULL;
-      char *form_password = NULL;
-
-      /* The username */
-      if (handle_forms) {
-        form_username = g_strdup (lines[begin++]);
-      } else {
-        begin++; /* Skip username element */
-      }
-      username = decrypt (lines[begin++]);
-
-      /* The password */
-      /* The element name has a leading '*' */
-      if (lines[begin][0] == '*') {
-        if (handle_forms) {
-          form_password = g_strdup (lines[begin++]);
-        } else {
-          begin++; /* Skip password element */
-        }
-        password = decrypt (lines[begin++]);
-      } else {
-        /* Maybe the file is broken, skip to the next block */
-        g_free (username);
-        break;
-      }
-
-      /* The action attribute for from the form element. This line
-       * exists in version 2 or above
-       */
-      if (version >= 2) {
-        begin++;
-
-        /* Version 3 has an extra line for further use */
-        if (version == 3)
-          begin++;
-      }
-
-      if (handle_forms && !realm &&
-          username && password &&
-          !g_str_equal (username, "") &&
-          !g_str_equal (form_username, "") &&
-          !g_str_equal (form_password, "*")) {
-        char *u = soup_uri_to_string (uri, FALSE);
-        /* We skip the '*' at the beginning of form_password. */
-        ephy_form_auth_data_store (u,
-                                   form_username,
-                                   form_password + 1,
-                                   username,
-                                   password,
-                                   NULL, NULL);
-        g_free (u);
-      } else if (!handle_forms && realm &&
-                 username && password &&
-                 !g_str_equal (username, "") &&
-                 form_username == NULL && form_password == NULL) {
-        char *u = soup_uri_to_string (uri, FALSE);
-        secret_password_store_sync (SECRET_SCHEMA_COMPAT_NETWORK,
-                                    SECRET_COLLECTION_DEFAULT,
-                                    u, password, NULL, NULL,
-                                    "user", username,
-                                    "domain", realm,
-                                    "server", uri->host,
-                                    "protocol", uri->scheme,
-                                    "port", (gint)uri->port,
-                                    NULL);
-      }
-
-      g_free (username);
-      g_free (password);
-      g_free (form_username);
-      g_free (form_password);
-    }
-
-    soup_uri_free (uri);
-    g_free (realm);
-  }
-
- out:
-  g_strfreev (lines);
-}
-#endif
-
-static void
-migrate_passwords (void)
-{
-#ifdef ENABLE_NSS
-  char *dest, *contents, *gecko_passwords_backup;
-  gsize length;
-  GError *error = NULL;
-
-  dest = g_build_filename (ephy_dot_dir (),
-                           "mozilla", "epiphany", "signons3.txt",
-                           NULL);
-  if (!g_file_test (dest, G_FILE_TEST_EXISTS)) {
-    g_free (dest);
-    dest = g_build_filename (ephy_dot_dir (),
-                             "mozilla", "epiphany", "signons2.txt",
-                             NULL);
-    if (!g_file_test (dest, G_FILE_TEST_EXISTS)) {
-      g_free (dest);
-      return;
-    }
-  }
-
-  if (!ephy_nss_glue_init ())
-    return;
-
-  if (!g_file_get_contents (dest, &contents, &length, &error)) {
-    g_free (dest);
-  }
-
-  parse_and_decrypt_signons (contents, FALSE);
-
-  /* Save the contents in a backup directory for future data
-     extraction when we support more features */
-  gecko_passwords_backup = g_build_filename (ephy_dot_dir (),
-                                             "gecko-passwords.txt", NULL);
-
-  if (!g_file_set_contents (gecko_passwords_backup, contents,
-                            -1, &error)) {
-    g_error_free (error);
-  }
-
-  g_free (gecko_passwords_backup);
-  g_free (contents);
-
-  ephy_nss_glue_close ();
-#endif
-}
-
-static void
-migrate_passwords2 (void)
-{
-#ifdef ENABLE_NSS
-  char *dest, *contents;
-  gsize length;
-  GError *error = NULL;
-
-  dest = g_build_filename (ephy_dot_dir (),
-                           "gecko-passwords.txt",
-                           NULL);
-  if (!g_file_test (dest, G_FILE_TEST_EXISTS)) {
-    g_free (dest);
-    return;
-  }
-
-  if (!ephy_nss_glue_init ())
-    return;
-
-  if (!g_file_get_contents (dest, &contents, &length, &error)) {
-    g_free (dest);
-  }
-
-  parse_and_decrypt_signons (contents, TRUE);
-  g_free (contents);
-
-  ephy_nss_glue_close ();
-#endif
-}
-
 /* History migration */
 
 static EphyHistoryService *history_service = NULL;
@@ -987,118 +698,29 @@ migrate_app_desktop_file_categories (void)
   ephy_web_application_free_application_list (web_apps);
 }
 
-/* https://bugzilla.gnome.org/show_bug.cgi?id=752738 */
 static void
-migrate_insecure_password (SecretItem *item)
+migrate_nothing (void)
 {
-  GHashTable *attributes;
-  SoupURI *soup_uri;
-  const char *original_uri;
-
-  attributes = secret_item_get_attributes (item);
-  original_uri = g_hash_table_lookup (attributes, URI_KEY);
-  soup_uri = soup_uri_new (original_uri);
-  if (soup_uri == NULL) {
-    g_warning ("Failed to convert URI %s to a SoupURI, insecure password will not be migrated", original_uri);
-    g_hash_table_unref (attributes);
-    return;
-  }
-
-  if (soup_uri->scheme == SOUP_URI_SCHEME_HTTP) {
-    char *new_uri;
-    GError *error = NULL;
-
-    new_uri = ephy_uri_to_https_security_origin (original_uri);
-
-    g_hash_table_replace (attributes, g_strdup (URI_KEY), new_uri);
-    secret_item_set_attributes_sync (item, EPHY_FORM_PASSWORD_SCHEMA, attributes, NULL, &error);
-    if (error != NULL) {
-      g_warning ("Failed to convert URI %s to https://, insecure password will not be migrated: %s", original_uri, error->message);
-      g_error_free (error);
-    }
-  }
-
-  g_hash_table_unref (attributes);
-  soup_uri_free (soup_uri);
-}
-
-static void
-migrate_insecure_passwords (void)
-{
-  SecretService *service;
-  GHashTable *attributes;
-  GList *items;
-  int default_profile_migration_version;
-  GError *error = NULL;
-
-  /* This is ephy *profile* migrator. It runs on a per-profile basis. i.e.
-   * each web app runs migrators separately. So this migration step could run
-   * once for a profile dir, then again far in the future when an old web app
-   * is opened. But passwords are global state, not stored in the profile dir,
-   * and we want to run this migration only once. This is tricky to fix, but
-   * it's easier if we relax the constraint to "never run this migrator if it
-   * has been run already for the default profile dir." That's because we don't
-   * really care if a couple web app passwords get converted from insecure to
-   * secure, which is not a big problem and indicates the user probably never
-   * uses Epiphany except for web apps anyway. We just don't want all the user's
-   * passwords to get converted mysteriously because he happens to open a web
-   * app. So check the migration version for the default profile dir and abort
-   * if this migrator has already run there. This way we avoid adding a new flag
-   * file to clutter the profile dir just to check if this migrator has run.
+  /* Used to replace migrators that have been removed. E.g. we used to have
+   * three password migrators that depended on NSS, but supporting ancient
+   * user profiles from almost a decade ago is not worth depending on NSS.
+   *
+   * Note that you cannot simply remove a migrator from the migrators struct,
+   * as that would mess up tracking of which migrators have been run.
    */
-  default_profile_migration_version = ephy_profile_utils_get_migration_version_for_profile_dir (ephy_default_dot_dir ());
-  if (default_profile_migration_version >= EPHY_INSECURE_PASSWORDS_MIGRATION_VERSION) {
-    LOG ("Skipping insecure password migration because default profile has already migrated");
-    return;
-  }
-
-  service = secret_service_get_sync (SECRET_SERVICE_LOAD_COLLECTIONS, NULL, &error);
-  if (error != NULL) {
-    g_warning ("Failed to get secret service proxy, insecure passwords will not be migrated: %s", error->message);
-    g_error_free (error);
-    return;
-  }
-
-  attributes = secret_attributes_build (EPHY_FORM_PASSWORD_SCHEMA, NULL);
-
-  items = secret_service_search_sync (service,
-                                      EPHY_FORM_PASSWORD_SCHEMA,
-                                      attributes,
-                                      SECRET_SEARCH_ALL | SECRET_SEARCH_UNLOCK | SECRET_SEARCH_LOAD_SECRETS,
-                                      NULL,
-                                      &error);
-  if (error != NULL) {
-    g_warning ("Failed to search secret service, insecure passwords will not be migrated: %s", error->message);
-    g_error_free (error);
-    goto out;
-  }
-
-  for (GList *l = items; l != NULL; l = l->next)
-    migrate_insecure_password ((SecretItem *)l->data);
-
-  g_list_free_full (items, g_object_unref);
-
-out:
-  g_object_unref (service);
-  g_hash_table_unref (attributes);
 }
 
 const EphyProfileMigrator migrators[] = {
   migrate_cookies,
-  migrate_passwords,
-  /* Yes, again! Version 2 had some bugs, so we need to run
-     migrate_passwords again to possibly migrate more passwords*/
-  migrate_passwords,
-  /* Very similar to migrate_passwords, but this migrates
-   * login/passwords for page forms, which we previously ignored */
-  migrate_passwords2,
+  migrate_nothing,
+  migrate_nothing,
+  migrate_nothing,
   migrate_history,
   migrate_tabs_visibility,
   migrate_web_app_links,
   migrate_new_urls_table,
   migrate_form_passwords_to_libsecret,
   migrate_app_desktop_file_categories,
-  migrate_insecure_passwords,
 };
 
 static gboolean
@@ -1134,7 +756,7 @@ ephy_migrator (void)
        EPHY_PROFILE_MIGRATION_VERSION, latest);
 
   for (i = latest; i < EPHY_PROFILE_MIGRATION_VERSION; i++) {
-    LOG ("Running migrator: %d of %d", i, EPHY_PROFILE_MIGRATION_VERSION);
+    LOG ("Running migrator: %d of %d", i + 1, EPHY_PROFILE_MIGRATION_VERSION);
 
     /* No need to run the password migration twice in a row. It
        appears twice in the list for the benefit of people that were
